@@ -13,6 +13,40 @@ jags.parallel <- function (data, inits, parameters.to.save, model.file = "model.
         inits
     }
     jags.model <- model.file
+
+    if( is.character( data ) && length(data) == 1
+                           && regexpr( "\\.txt$", data ) > 0 ) {
+    ## 1. 'data' looks like a file name [UNDOCUMENTED!]
+    if ( all( basename( data ) == data )) {
+      fn2 <- file.path( working.directory, data )
+      if (normalizePath(fn2)!=normalizePath(data)) {  ## file.copy() to same place trashes the file
+        try( file.copy(fn2 , data, overwrite = TRUE ) )
+      }
+    }
+    if ( !file.exists( data ) ) {
+      stop("File",data,"does not exist")
+    }
+    if (file.info(data)["size"]==0) {
+      stop("Empty data file ",data)
+    }
+    e    <- new.env()
+    eval( parse( data ), e )
+    data <- as.list( e )
+  } else if( is.character( data ) ||
+             ( is.list( data ) && all( sapply( data,is.character ) ) ) ){
+    ## 2. data is a character vector or a list of character
+    dlist          <- lapply( as.list( data ), get, envir = parent.frame( 1 ) )
+    names( dlist ) <- unlist( data )
+    data           <- dlist
+  } else if( !is.list( data ) ){
+    stop( "data must be a character vector of object names, a list of object names, or a list of objects" )
+  }
+
+   list2env(data, envir=envir )
+
+
+
+
     .runjags <- function() {
         jagsfit <- jags(data = eval(expression(data)), inits = jags.inits,
             parameters.to.save = eval(expression(jags.params)),
@@ -22,11 +56,11 @@ jags.parallel <- function (data, inits, parameters.to.save, model.file = "model.
             working.directory = eval(expression(working.directory)),
             jags.seed = eval(expression(jags.seed)), progress.bar = "none",
             digits = eval(expression(digits)), RNGname = eval(expression(RNGname)),
-            jags.module = eval(expression(jags.module)), )
+            jags.module = eval(expression(jags.module)) )
         return(jagsfit)
     }
     cl <- makeCluster(n.cluster, methods = FALSE)
-    clusterExport(cl, c(data, "mcmc", "mcmc.list", export_obj_names ), envir = envir)
+    clusterExport(cl, c(names(data), "mcmc", "mcmc.list", export_obj_names ), envir = envir)
     clusterSetRNGStream(cl, jags.seed)
     tryCatch(res <- clusterCall(cl, .runjags), finally = stopCluster(cl))
     result <- NULL
